BackendPoolStats

Trait BackendPoolStats 

pub trait BackendPoolStats {
    // Required methods
    fn active_connections(&self) -> u32;
    fn idle_connections(&self) -> u32;
    fn max_connections(&self) -> u32;
    fn pending_connections(&self) -> u32;
}
Extension trait for backends that support connection pooling statistics.

Required Methods

fn active_connections(&self) -> u32

Returns the current number of active connections.

fn idle_connections(&self) -> u32

Returns the current number of idle connections.

fn max_connections(&self) -> u32

Returns the maximum pool size.

fn pending_connections(&self) -> u32

Returns the number of connections waiting to be acquired.

Implementors