pub enum TenancyStrategy {
SharedSchema(SharedSchemaConfig),
SchemaPerTenant(SchemaPerTenantConfig),
DatabasePerTenant(DatabasePerTenantConfig),
}Expand description
The tenancy strategy configuration.
This enum defines how tenant isolation is implemented at the database level.
Variants
All tenants share the same schema with a tenant_id column.
SchemaPerTenant(SchemaPerTenantConfig)
Each tenant has a separate database schema.
DatabasePerTenant(DatabasePerTenantConfig)
Each tenant has a separate database.
Implementations
Sourceimpl TenancyStrategy
impl TenancyStrategy
Sourcepub fn isolation_level(&self) -> IsolationLevel
pub fn isolation_level(&self) -> IsolationLevel
Returns the isolation level of this strategy.
Returns true if this strategy uses a shared connection pool.