pub enum SearchModifier {
Show 16 variants
Exact,
Contains,
Text,
Not,
Missing,
Above,
Below,
In,
NotIn,
Identifier,
Type(String),
OfType,
CodeOnly,
Iterate,
TextAdvanced,
CodeText,
}Expand description
Search modifiers that can be applied to search parameters.
See: https://build.fhir.org/search.html#modifiers
Variants
Exact
Exact string match (string parameters).
Contains
Contains substring (string parameters).
Text
Text search (token parameters).
Not
Negation - exclude matches.
Missing
Match if value is missing.
Above
Match codes above in hierarchy (token parameters).
Below
Match codes below in hierarchy (token parameters).
In
Match codes in a value set (token parameters).
NotIn
Match codes not in a value set (token parameters).
Identifier
Match on identifier (reference parameters).
Type(String)
Specify reference type (reference parameters).
OfType
Match on type (token parameters for polymorphic elements).
CodeOnly
Match on code only (token parameters).
Iterate
Iterate through results (_include modifier).
TextAdvanced
Advanced text search with synonyms and linguistic matching (FHIR v6.0.0).
This modifier enables sophisticated text matching that may include:
- Synonym expansion
- Linguistic stemming
- Fuzzy matching
Requires external terminology service integration.
CodeText
Match on code text/display value (token parameters, FHIR v6.0.0).
Searches the text/display value of a CodeableConcept or Coding rather than the code itself.
Implementations
Sourceimpl SearchModifier
impl SearchModifier
Sourcepub fn parse(s: &str) -> Option<Self>
pub fn parse(s: &str) -> Option<Self>
Parses a modifier string, returning None for unknown modifiers.
Sourcepub fn is_valid_for(&self, param_type: SearchParamType) -> bool
pub fn is_valid_for(&self, param_type: SearchParamType) -> bool
Returns true if this modifier is valid for the given parameter type.