pub enum SearchPrefix {
Eq,
Ne,
Gt,
Lt,
Ge,
Le,
Sa,
Eb,
Ap,
}Expand description
Comparison prefixes for search parameters.
See: https://build.fhir.org/search.html#prefix
Variants
Eq
Equal (default).
Ne
Not equal.
Gt
Greater than.
Lt
Less than.
Ge
Greater than or equal.
Le
Less than or equal.
Sa
Starts after.
Eb
Ends before.
Ap
Approximately equal.
Implementations
Sourceimpl SearchPrefix
impl SearchPrefix
Sourcepub fn extract(value: &str) -> (Self, &str)
pub fn extract(value: &str) -> (Self, &str)
Extracts a prefix from the beginning of a value string.
Returns the prefix and the remaining value.
Sourcepub fn is_valid_for(&self, param_type: SearchParamType) -> bool
pub fn is_valid_for(&self, param_type: SearchParamType) -> bool
Returns true if this prefix is valid for the given parameter type.