pub struct SearchParamFullCapability {
pub name: String,
pub param_type: SearchParamType,
pub definition: Option<String>,
pub modifiers: HashSet<String>,
pub prefixes: HashSet<String>,
pub chaining: Option<ChainingCapability>,
pub target_types: Vec<String>,
pub components: Vec<CompositeComponent>,
pub shall_support: bool,
}Expand description
Full capability declaration for a search parameter.
This provides complete information about what features are supported for a specific search parameter on a specific resource type.
Fields
name: StringThe parameter name (e.g., “name”, “identifier”).
param_type: SearchParamTypeThe parameter type.
definition: Option<String>Canonical URL of the SearchParameter definition.
modifiers: HashSet<String>Supported modifiers for this parameter.
prefixes: HashSet<String>Supported comparison prefixes for this parameter.
chaining: Option<ChainingCapability>Chaining capability for reference parameters.
target_types: Vec<String>Target resource types (for reference parameters).
components: Vec<CompositeComponent>Components (for composite parameters).
shall_support: boolWhether this parameter is required in capability statements.
Implementations
Sourceimpl SearchParamFullCapability
impl SearchParamFullCapability
Sourcepub fn new(name: impl Into<String>, param_type: SearchParamType) -> Self
pub fn new(name: impl Into<String>, param_type: SearchParamType) -> Self
Creates a new capability for a search parameter.
Sourcepub fn with_definition(self, url: impl Into<String>) -> Self
pub fn with_definition(self, url: impl Into<String>) -> Self
Sets the definition URL.
Sourcepub fn with_modifiers<I, S>(self, modifiers: I) -> Self
pub fn with_modifiers<I, S>(self, modifiers: I) -> Self
Adds supported modifiers.
Sourcepub fn with_chaining(self, chaining: ChainingCapability) -> Self
pub fn with_chaining(self, chaining: ChainingCapability) -> Self
Sets chaining capability.
Sourcepub fn with_targets<I, S>(self, targets: I) -> Self
pub fn with_targets<I, S>(self, targets: I) -> Self
Sets target types for reference parameters.
Sourcepub fn with_components(self, components: Vec<CompositeComponent>) -> Self
pub fn with_components(self, components: Vec<CompositeComponent>) -> Self
Sets components for composite parameters.
Sourcepub fn supports_modifier(&self, modifier: &str) -> bool
pub fn supports_modifier(&self, modifier: &str) -> bool
Returns whether a specific modifier is supported.
Sourcepub fn supports_prefix(&self, prefix: &str) -> bool
pub fn supports_prefix(&self, prefix: &str) -> bool
Returns whether a specific prefix is supported.
Sourcepub fn is_composite(&self) -> bool
pub fn is_composite(&self) -> bool
Returns whether this is a composite parameter.
Sourcepub fn supports_chaining(&self) -> bool
pub fn supports_chaining(&self) -> bool
Returns whether this is a reference parameter with chaining support.