pub struct SearchValue {
pub prefix: SearchPrefix,
pub value: String,
}Expand description
A single search value with optional prefix.
Fields
prefix: SearchPrefixThe comparison prefix.
value: StringThe value to search for.
Implementations
Sourceimpl SearchValue
impl SearchValue
Sourcepub fn new(prefix: SearchPrefix, value: impl Into<String>) -> Self
pub fn new(prefix: SearchPrefix, value: impl Into<String>) -> Self
Creates a new search value with the given prefix and value.
Sourcepub fn eq(value: impl Into<String>) -> Self
pub fn eq(value: impl Into<String>) -> Self
Creates a search value with the default (eq) prefix.
Sourcepub fn token(system: Option<&str>, code: impl Into<String>) -> Self
pub fn token(system: Option<&str>, code: impl Into<String>) -> Self
Creates a token search value with optional system and code.
Format: [system]|[code] or just [code]
Sourcepub fn token_system_only(system: impl Into<String>) -> Self
pub fn token_system_only(system: impl Into<String>) -> Self
Creates a token search value with system only (no code).
Format: [system]|
Sourcepub fn of_type(
type_system: impl Into<String>,
type_code: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn of_type( type_system: impl Into<String>, type_code: impl Into<String>, value: impl Into<String>, ) -> Self
Creates a search value for :of-type modifier with three-part format.
Format: [type-system]|[type-code]|[value]
This is used with the :of-type modifier to search typed identifiers. The format specifies the identifier type (system and code) followed by the identifier value to match.
Example
ⓘ
// Search for SSN identifier with value "123-45-6789"
SearchValue::of_type(
"http://terminology.hl7.org/CodeSystem/v2-0203",
"SS",
"123-45-6789"
)Trait Implementations
Sourceimpl Clone for SearchValue
impl Clone for SearchValue
Sourcefn clone(&self) -> SearchValue
fn clone(&self) -> SearchValue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchValue
impl Debug for SearchValue
Sourceimpl<'de> Deserialize<'de> for SearchValue
impl<'de> Deserialize<'de> for SearchValue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more