pub trait BackendPoolStats {
// Required methods
fn active_connections(&self) -> u32;
fn idle_connections(&self) -> u32;
fn max_connections(&self) -> u32;
fn pending_connections(&self) -> u32;
}Expand description
Extension trait for backends that support connection pooling statistics.
Required Methods
Sourcefn active_connections(&self) -> u32
fn active_connections(&self) -> u32
Returns the current number of active connections.
Sourcefn idle_connections(&self) -> u32
fn idle_connections(&self) -> u32
Returns the current number of idle connections.
Sourcefn max_connections(&self) -> u32
fn max_connections(&self) -> u32
Returns the maximum pool size.
Sourcefn pending_connections(&self) -> u32
fn pending_connections(&self) -> u32
Returns the number of connections waiting to be acquired.